#
# spec file for package perl-Date-Manip
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Date-Manip
Name:           perl-Date-Manip
Version:        6.92
Release:        1.2
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Date manipulation routines
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SB/SBECK/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.67_01
BuildRequires:  perl(Test::Inter) >= 1.09
%{perl_requires}

%description
Date::Manip is a series of modules designed to make any common date/time
operation easy to do. Operations such as comparing two times, determining a
date a given amount of time from another, or parsing international times
are all easily done. It deals with time as it is used in the Gregorian
calendar (the one currently in use) with full support for time changes due
to daylight saving time.

From the very beginning, the main focus of Date::Manip has been to be able
to do ANY desired date/time operation easily. Many other modules exist
which may do a subset of these operations quicker or more efficiently, but
no other module can do all of the operations available in Date::Manip.

Date::Manip has functionality to work with several fundamental types of
data.

* *dates*

The word date is used extensively here and is somewhat misleading. In
Date::Manip, a date consists of three pieces of information: a calendar
date (year, month, day), a time of day (hour, minute, second), and time
zone information. Calendar dates and times are fully handled. Time zones
are handled as well, but depending on how you use Date::Manip, there may be
some limitations as discussed below.

* *delta*

A delta is an amount of time (i.e. the amount of time between two different
dates). Think of it as the duration of an event or the amount of time
between two dates.

A delta refers only to an amount of time. It includes no information about
a starting or ending date/time. Most people will think of a delta as an
amount of time, but the term 'time' is already used so much in this module
that I didn't want to use it here in order to avoid confusion.

* *recurrence*

A recurring event is something which occurs on a regular recurring basis.

* *holidays* and *events*

Holidays and events are basically named dates or recurrences.

Among other things, Date::Manip allow you to:

* ***

Enter a date in practically any format you choose.

* ***

Compare two dates, entered in widely different formats to determine which
is earlier.

* ***

Extract any information you want from a date using a format string similar
to the Unix date command.

* ***

Determine the amount of time between two dates, or add an amount of time (a
delta) to a date to get a second date.

* ***

Work with dates using international formats (foreign month names, 12/10/95
referring to October rather than December, etc.).

* ***

Convert dates from one timezone to another.

* ***

To find a list of dates where a recurring event happens.

Each of these tasks is trivial (one or two lines at most) with this
package.

%prep
%autosetup  -n %{cpan_name}-%{version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README README.first
%license LICENSE

%changelog
* Thu Jun  8 2023 Tina Müller <timueller+perl@suse.de>
- updated to 6.92
  see /usr/share/doc/packages/perl-Date-Manip/Changes
  6.92  2023-06-07
  - Time zone fixes
    Newest zoneinfo data (tzdata 2023c).
  - Documentation fixes
    Typo fix. Reported by Derek Terveer
* Thu Mar  2 2023 Tina Müller <timueller+perl@suse.de>
- updated to 6.91
  see /usr/share/doc/packages/perl-Date-Manip/Changes
  6.91  2023-03-01
  - Fixed bug where timezone alias wasn't handled
    On linux systems configured to be in a timezone that is an alias,
    the system timezone wasn't recognized, and it defaulted to GMT.
    This is now fixed. Patch supplied by Sandi Wallendahl (GitHub #43)
* Sat Dec  3 2022 Tina Müller <timueller+perl@suse.de>
- updated to 6.90
  see /usr/share/doc/packages/perl-Date-Manip/Changes
* Fri Sep  2 2022 Tina Müller <timueller+perl@suse.de>
- updated to 6.89
  see /usr/share/doc/packages/perl-Date-Manip/Changes
* Fri Jun  3 2022 Tina Müller <timueller+perl@suse.de>
- updated to 6.88
  see /usr/share/doc/packages/perl-Date-Manip/Changes
  6.88  expected 2022-06-01
  - Time zone fixes
    There were no new timezone fixes on 2022-03-01, so no release made
    then.
    Newest zoneinfo data (tzdata 2022a).
  6.87  expected 2022-03-01
  - Bug fixes
    The package was being generated with an incorrect MANIFEST file.
    This is now fixed. RT 140075
* Tue Nov 16 2021 Tina Müller <timueller+perl@suse.de>
- updated to 6.86
  see /usr/share/doc/packages/perl-Date-Manip/Changes
  6.86  2021-11-15
  - Change warn to carp
    All warnings are now issued with the carp command rather than warn.
    Requested in GitHup pull request #18, but that request was not used
    because it only changed the uses in the Date::Manip::Date module.
  - Bug fixes
    Fixed a bug where the next/prev Date::Manip::Recur methods gave
    incorrect results when there are no dates that match the criteria.
    (GitHub #36)
  - Time zone fixes
    There were no new timezone fixes on 2021-06-01 or 2021-09-01, so no
    releases made then.
    Newest zoneinfo data (tzdata 2021e). (GitHub #37)
* Tue Mar  2 2021 Tina Müller <timueller+perl@suse.de>
- updated to 6.85
  see /usr/share/doc/packages/perl-Date-Manip/Changes
  6.85  2021-03-01
  - Test fixes
    Missed some tests that were failing.
  6.84  2021-03-01
  - Time zone fixes
    Newest zoneinfo data (tzdata 2021a).
  - Language fixes
    Corrections and additions to Italian. Patch supplied by Leo
    Cacciari (GitHub #33)
* Tue Dec  1 2020 Tina Müller <timueller+perl@suse.de>
- updated to 6.83
  see /usr/share/doc/packages/perl-Date-Manip/Changes
  6.83  2020-12-01
  - Time zone fixes
    No new zoneinfo data so no release on 2020-09-01.
    Newest zoneinfo data (tzdata 2020d). Requested by Shawn Carroll
    (GitHub #32)
* Tue Jun  2 2020 Tina Müller <timueller+perl@suse.de>
  updated to 6.82
  see /usr/share/doc/packages/perl-Date-Manip/Changes
  6.82  2020-06-01
  - Time zone fixes
    Newest zoneinfo data (tzdata 2020a).
* Tue Mar  3 2020 <timueller+perl@suse.de>
- updated to 6.81
  see /usr/share/doc/packages/perl-Date-Manip/Changes
  6.81  2020-03-01
  - Messed up the 6.80 package. This release fixes it.
  6.80  2020-03-01
  - Missed Changes entry for previous version.
    Reported by Tina Muller (GitHub #31)
  6.79  2019-12-01
  - Time zone fixes
    Newest zoneinfo data (tzdata 2019c).
* Tue Dec  3 2019 <timueller+perl@suse.de>
- updated to 6.79
  see /usr/share/doc/packages/perl-Date-Manip/Changes
* Tue Sep  3 2019 <timueller+perl@suse.de>
- updated to 6.78
  see /usr/share/doc/packages/perl-Date-Manip/Changes
  6.78  2019-08-29
  - Time zone fixes
    Newest zoneinfo data (tzdata 2019b).
  - Documentation fixes
    Fixed a broken link. Mohammad S Anwar (GitHub #29)
* Tue Jun  4 2019 Stephan Kulow <coolo@suse.com>
- updated to 6.77
  see /usr/share/doc/packages/perl-Date-Manip/Changes
  6.77  2019-06-01
  - Time zone fixes
    Newest zoneinfo data (tzdata 2019a).
* Fri Mar  1 2019 Stephan Kulow <coolo@suse.com>
- updated to 6.76
  see /usr/share/doc/packages/perl-Date-Manip/Changes
  6.76  2019-03-01
  - Fixed bug in Date::Manip::Date::list_holidays.
    It was using 'now' instead of the stored date. Douglas DeStafeno
  - Reordered TZ detection methods
    Moved checking the tzdata files to lower priority to avoid a pretty
    unusual situation in docker. Sven Nierlein (GitHub #20)
  - Time zone fixes
    Newest zoneinfo data (tzdata 2018i). Requested by Shawn C Carroll
    (GitHub #28)
  6.75  2018-12-03
  - Fixed packaging problems
    Version 6.74 was not packaged correctly. Version wasn't set
    correctly in a few files and there were invalid entries in
    Makefile.PL. RT 127870.
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 6.75
  see /usr/share/doc/packages/perl-Date-Manip/Changes
  6.74  2018-12-01
  - Removed travis file from the tarball
    The tarball had a .travis.yml file in it that wasn't in the MANIFEST
    file. Since the MANIFEST file is automatically generated by the perl
    mkmanifest tool, since it didn't see the .travis.yml file, I have
    excluded it from the tarball. Reported by Mohammad S Anwar on GitHub
    (#23)
  - Time zone fixes
    Newest zoneinfo data (tzdata 2018e)
* Mon Sep  3 2018 pgajdos@suse.com
- updated to 6.73
  /usr/share/doc/packages/perl-Date-Manip/Changes
  6.73  2018-09-01
  - Fixed math on non-64-bit architectures
    Much of the math in Date::Manip::Base is in a 'use integer' section.
    This math can overflow in some cases in non-64-bit architectures.
    Fixed the cases where this would reasonably occur. Reported by
    Daniel Albers (GitHub #22). Also reported and tested in RT 126052.
  - Bug in normalizing estimated business deltas
    While working on the non-64-bit issue, it uncovered a bug where
    normalizing estimated business deltas was wrong. It had never been
    reported, and it was only off by a couple seconds in some rare
    situations.
- do not exclude 32-bit platforms from build, the issue is solved
  via RT bug 126052 [bsc#1086297]
* Thu Jun  7 2018 coolo@suse.com
- updated to 6.72
  see /usr/share/doc/packages/perl-Date-Manip/Changes
  6.72  2018-06-06
  - Fixed recurrence bug
    The fix in the previous version for a rare recurrence problem broke
    another recurrence form. It is now corrected. Michael Schout (GitHub
    [#20])
  - Fixed version problem
    The wrong version was included in two files for some reason. This is
    fixed.
  - Documentation fixes
    Fixed a grammatical error reported by Xavier Guimard (GitHub #19).
  6.71  2018-06-01
  - Fixed an extremely rare problem with recurrences
    It is possible to specify a recurrence that never produces a valid
    date. In these cases, looking for dates went into an infinite loop.
    The MaxRecurAttempts config variable was added which will stop that
    from happening. If no occurrence was found, an error condition will
    be set. Dean Hamstead (RT 123708)
  - Changes file supported
    It was requested that I include a valid Changes file. I wrote a
    simple script to convert the Change6.pod file into a valid Change
    file. The Changes6.pod file is still the canonical source of this
    information! Requested by H. Merijn Brand
  - Fix for timezone determination
    On MacOS X High Sierra, some of the timezone files were symlinks,
    but not properly followed. This was fixed by Stu Tomlinson (GitHub
    [#15]).
  - Time zone fixes
    Newest zoneinfo data (tzdata 2018e)
  - Documentation fixes
    Minor fix provided by Mohammad S Anwar (GitHub #17)
* Wed Mar 21 2018 ro@suse.de
- set excludearch for 32bit platforms, package fails in testsuite
  (bsc#1086297)
* Fri Mar  2 2018 coolo@suse.com
- updated to 6.70
  * Improved handling of deltas.
  * Deprecated some parts of Date::Manip::Delta
  - Deprecation of TZ postponed
  - Some speed improvements
  - Changed behavior if timezone not determined
  - Fixed Makefile.PL
  - Time zone fixes
  - Documentation fixes
  see /usr/share/doc/packages/perl-Date-Manip/Changes
* Sat Sep  2 2017 coolo@suse.com
- updated to 6.60
  see /usr/share/doc/packages/perl-Date-Manip/Changes
* Fri Jun  2 2017 coolo@suse.com
- updated to 6.59
  see /usr/share/doc/packages/perl-Date-Manip/Changes
* Fri Mar  3 2017 coolo@suse.com
- updated to 6.58
  see /usr/share/doc/packages/perl-Date-Manip/Changes
* Fri Dec  2 2016 coolo@suse.com
- updated to 6.57
  see /usr/share/doc/packages/perl-Date-Manip/Changes
* Sat Sep 10 2016 coolo@suse.com
- updated to 6.56
  see /usr/share/doc/packages/perl-Date-Manip/Changes
* Wed Jun  1 2016 coolo@suse.com
- updated to 6.54
  see /usr/share/doc/packages/perl-Date-Manip/Changes
* Tue Mar  8 2016 coolo@suse.com
- updated to 6.53
  see /usr/share/doc/packages/perl-Date-Manip/Changes
* Wed Dec  2 2015 coolo@suse.com
- updated to 6.52
  see /usr/share/doc/packages/perl-Date-Manip/Changes
* Wed Sep  2 2015 coolo@suse.com
- updated to 6.51
  see /usr/share/doc/packages/perl-Date-Manip/Changes
* Sun Jun  7 2015 coolo@suse.com
- updated to 6.50
  see /usr/share/doc/packages/perl-Date-Manip/Changes
* Sun Apr 19 2015 coolo@suse.com
- updated to 6.49
  see /usr/share/doc/packages/perl-Date-Manip/Changes
* Fri Mar  7 2014 coolo@suse.com
- updated to 6.43
* Mon Dec  9 2013 coolo@suse.com
- updated to 6.42
  * Added ParseDateFormat function
  Added the ParseDateFormat function to the DM6 functional interface
  in response to RT 89286.
  * Added Common Log format
  Added the date format used in apache logs: 11/Oct/2000:13:55:36 -0700
  RT 89286.
  * Time zone fixes
  Newest zoneinfo data (tzdata 2013h)
  * Bug fixes
  Fixed a bug where dates of the form of a delta with a timezone attached
  (i.e. "1 day ago at midnight UTC") failed.  RT 89256
  Fixed a bug where events handling gave a warning if there were no events
  that applied.  RT 90344
* Fri Oct  4 2013 coolo@suse.com
- updated to 6.41
  Removed a .swp file accidentally left in the package.  RT 85845
  Fixed a bug in parse_format where times between 00:00:00 and 01:00:00 weren't
  parsed correctly.  Ole Nomann Thomsen
  Fixed generated META.* files to not require Module::Build 0.39.  RT 86137
  Fixed a bug where parse_format did not work with a '%%s' format.  RT 87498
  Fixed a bug where find_encoding wasn't imported from the Encode module.  RT 87665
  Fixed a bug where recurrences with no interval did not work if a start and
  end date were specified, and no dates fell in that range.  Jan Pradac
  * Time zone fixes
  Newest zoneinfo data (tzdata 2013d)
* Tue Jun  4 2013 coolo@suse.com
- updated to 6.40
  documentation is no longer generated for Date::Manip::TZ::* and
  Date::Manip::Offset::* modules.
  Newest zoneinfo data (tzdata 2013c)
  Added the $mode argument to ParseDateDelta
  The ParseDateDelta function (in functional interface) did not allow you
  to force a parsed delta to semi or approx where appropriate.  This
  was added.  Based on RT 82991).
  Added get_config method
  The get_config method was added to all classes.  Suggested by Philippe Poilbarbe.
  Language fixes
  Fixed a German language problem.  Gosta Oelstrom
  Documentation fixes
  Documented workaround for dmake problem in strawberry perl.  Discussed on
  perlmonks and RT 79837.
  Clarified the Examples page.  Winston Heng
* Tue Mar  6 2012 coolo@suse.com
- updated to 6.31
  * Added extended formats to printf method.
  * Can now parse formats where the time and zone are not adjacent
  * Added PeriodTimeSep config variable.
  * Holidays can be used as date strings
  * Added new recur modifiers
  * Tons of new test cases and bug fixes
* Fri Jan 13 2012 vcizek@suse.com
- update to 6.30
  * Removed some deprecated config variables
  * Reworked deltas
  * Modified Delta_Format
  * Time zone fixes
  * Better handling of undef in DM6
  * Bug fixes
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Thu Sep  1 2011 pascal.bleser@opensuse.org
- update to 6.25:
  * relaxed one constraint in ISO 8601 dates: a time separated by whitespace
    from the date can use a single digit hour
  * set official removal dates for old config variables; config variables will
    be removed 2 years after they are deprecated (except for the TZ variable
    which, due to it's wide use, will be kept for 4 years)
  * time zone fixes: newest zoneinfo data (tzdata 2011i)
* Tue Jun 14 2011 vcizek@novell.com
- update to 6.24
  New features
    Spaces are ignored in the SetDate/ForceDate config values.  Zsban Ambrus
  Bug fixes
    Fixed a bug where 'in one week' wasn't correctly parsed.  E. M. Shtern
    Fixed a bug where options passed in to the 'new' as a listref weren't handled
    properly.  Zsban Ambrus
  Time zone fixes
    Newest zoneinfo data (tzdata 2011g)
* Mon Apr 18 2011 vcizek@novell.com
- update to 6.23
    Bug fixes
    Fixed a bug where GlobalCnf wasn't working. Peter Edwards
    Improved error messages in a few cases.
    Fixed a bug where one invalid date/timezone check was ignored. Morten
    Bjornsvik
    Fixed a bug where '$base2 = new Date::Manip::Base $base1' wasn't
    working. RT 67143
    Fixed a bug where passing dates in to the Recur->dates method failed.
    RT 67144
    Fixed a bug where the mode wasn't being preserved correctly for a
    delta. RT 67150
    Fixed a bug in recurrences where a base date outside of a date range
    with a very uncommon recurrence format would not work correctly.
    Fixed a problem where the '%%s' printf option didn't work in GMT.
    Time zone fixes
    Newest zoneinfo data (tzdata 2011f)
* Wed Mar  9 2011 vcizek@novell.com
- update to 6.22
  Time zone fixes:
  Newest zoneinfo data (tzdata 2011b).
  Fixed a bug where the gmtoff method of getting the local timezone was broken.
  Fixed the 'env' method of determining the local time zone to allow the
  value to be an offset of seconds since UTC.  This allows the VMS
  SYS$TIMEZONE_DIFFERENTIAL variable to work correctly.  Martin Zinser.
  Removed the SYS$TIMEZONE_RULE method from VMS since the value stored there
  is not the name of a timezone (it's a rule in a non-standard format).  Based
  on discussion with Martin Zinser.
  Language fixes:
  The module will now die if a language module cannot be loaded (most
  likely due to a YAML::Syck issue).  Based on discussion with Martin Zinser.
  Documentation fixes:
  Added a sample config file document.  Based on discussion with Rich Duzenbury.
* Wed Jan 19 2011 vcizek@novell.com
- update to 6.21
  New features
  - Deltas may now contain spelled out numbers, so 'in 2 weeks' and 'in two weeks'
    will both work.  Daniel Shahaf
  Bug fixes
  - Fixed a bug where week_of_year didn't work in some cases.  Chris Eveland.
  - Fixed a minor potential bug.  Geraint Edwards.
  Time zone fixes
  - Updated windows time zone aliases.  Daniel Harding
  Language fixes
  - Added Norwegian.  Glenn Sogn
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Thu Oct 21 2010 anicka@suse.cz
- update to 6.14
  * Date::Manip 5.xx and 6.xx are both installed automatically,
  and the correct one will be chosen.
  * Fixed a bug where recurrence handling was broken.  RT 62128
  * documentation was cleaned up to be easier to read, and better
  organized.
* Mon Oct 18 2010 anicka@suse.cz
- update to 6.13
  * Added the input methods to Date::Manip::Date and
  Date::Manip::Delta.
  * The 'date +%%z' command will also be used to determine
  the timezone.
  * bugfixes
* Thu Sep 30 2010 anicka@suse.cz
- update to 6.12
  * With better support for international character sets, the old
  IntCharSet config variable is deprecated.
  * Added the Encoding config variable.
  * Now supports parsing the EXIF date format.
  * bugfixes
* Wed Jul 21 2010 coolo@novell.com
- keep the obsoletes/provides of 11.1 renames
* Tue Jul 20 2010 chris@computersalat.de
- update to 6.11
  - Fixed a problem in Build.PL that had an incorrect module requirement.
- Version 6.10  2010-04-29
  Fixed a bug where Date_ConvTZ not working correctly with timezones specified
    by offset.  Chris Butler
  Fixed a documentation bug in Date::Manip::TZ where "stdonly" was listed as the
    default value for $dstflag, but in actuality, "std" is the default.
  Changed Date::Manip::TZ::zone so "dst" is sometimes the default $dstflag.
    Based on the bug report by Chris Butler.
  OpenUNIX puts a colon at the start of some timezones. It's removed.  Jean Hassler
  Fixed a bug where business mode calculations involving minutes was not handled
    correctly.  Damien Moore
  * ** Combined 5.xx and 6.xx releases into one distribution so cpan/cpanp will
    work correctly.
  Newest zoneinfo data (tzdata 2010i)
  Fixed a bug where business mode calculations failed in some cases.  RT 56638
  Converted tests to Test::Inter
- recreated by cpanspec 1.78
- noarch pkg
* Fri Feb 26 2010 anicka@suse.cz
- update to 6.07
  * Added dm_zdump example script.
  * Minor bug where %%Z printf format didn't always work.
  * Improved TZ::periods functionality
  * Fixed bug in Date_ConvTZ where empty values weren't defaulting
  to local timezone.
  * Fixed a couple of problems in the generated timezones for some
  odd cases (America/Resolute and Asia/Tehran).
  * Added support for 5pm back in (it was omitted accidentally).
  * Fixed a minor warning.
  * Some additional speedups.
  * Newest zoneinfo data.
  * Fixed bug in Date_TimeZone where it wasn't returning
  the timezone.
* Sat Dec 12 2009 chris@computersalat.de
- update to 6.05
  * Significant speedups. Thanks to Moritz Lenz and BrowserUK on perlmonks for
    suggestions (and a number of other people on perlmonks for suggestions
    that I did not end up using, but which provided a great discussion).
  * Reduced the precision of 1 test to avoid a rounding difference when using
    a perl compiled with uselongdouble.  Andreas Koenig
  * Fixed a bug in parse_date where the current time was getting used instead
    of the documented 00:00:00
  * Bug fix where DateCalc didn't work with $mode in some cases.
  * Fixed Makefile.PL/Build.PL to hanle Win32::TieRegistry requirement.
  * Changed %%z printf behavior back to 5.xx and added %%N format. Gilles Lamiral
  * Fixed bug where non-English Windows versions didn't get the timezone. Thanks
    to Rene Schickbauer for testing.
- cleanup spec
  * added cpan_name
  * sort tags
  * fix build-/deps
  * update desc
  * move changelog to .changes
- added perl-macros
  * perl_gen_filelist
* Wed Jul 23 2008 anicka@suse.cz
- update to 5.54
  * Final changes to meet requirements on http://cpants.perl.org/
- rename from perl-DateManip to perl-Date-Manip according to cpan
* Wed May  7 2008 lrupp@suse.de
- update to 5.50:
  * Corrected typo in %%G and %%L format descriptions
  * Added "ereyesterday"
  * Added new timezones
  * Added Build.PL and several other things to meet requirements on
    http://cpants.perl.org/
- remove INSTALL, added LICENSE and README.FIRST to doc
- build parallel
* Mon Mar 10 2008 anicka@suse.cz
- update to 5.48
  * Language fix for Danish.
  * Language fix for German.
  * New timezones.
  * Minor documentation improvement.
  * Revised some of the docs about Y2K (given that it's in the past)
  and the 2007 US daylight saving time rule changes.
  * bugfixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan  6 2006 anicka@suse.cz
- update to 5.44
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 21 2003 rommel@suse.de
- update to version 5.42a
- using perl_vendorlib and perl_vendorarch instead of
  perl_archlib and perl_sitearch
* Sun Jun 22 2003 coolo@suse.de
- package directories
* Sun May 25 2003 ro@suse.de
- remove unpackaged files from buildroot
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Fri Jun 22 2001 grimmer@suse.de
- Update to version 5.40
- use more perl macros in spec file
* Tue Nov  7 2000 grimmer@suse.de
- added .packlist to file list and removed BuildRoot path with sed
* Tue Nov  7 2000 grimmer@suse.de
- initial version (5.39)
